# About

**Brittle Wit is a Twitter Lib for Python.**

- It uses [asyncio](https://docs.python.org/3/library/asyncio.html), [aiohttp](http://aiohttp.readthedocs.org/en/stable/), and Python 3.5+ (async/await).
- It is rigorously polite in its adherence to [Twitter's rate limits](https://dev.twitter.com/rest/public/rate-limiting).
- It scales well.
- It works as a library or a server.

## Warning

I started developing this package months ago. I wanted to create some tools for
for media company agenda management. But, I ran out of safety-net cash, and had
to go back to a 9–5 (on top of my Ph.D. work). Consequently, this library is
unfinished and certainly buggy. I'm releasing it earlier than I'd prefer as a
mean of facilitating replicability for a post I wrote on Medium.

Developer, beware.

## Installation

From a Python 3.5 environment,

```bash
pip install brittle_wit
```
